package imagecomparer.gui;

import javax.swing.*;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.io.File;

/**
 * The FileSelectedListener
 */
interface FileSelectListener {

    /**
     * Executed when new file has been selected.
     *
     * @param file The selected file
     */
    public void fileSelected(File file);
}

/**
 * Class:           imagecomparer.gui.FileSelectBox
 * Version:         0.9
 * Date:            2004-04-19 14:36:35
 *
 * Description:     Create box containing text fileld and "open" button.
 *
 * COPYRIGHT:
 *
 * This software module was originally developed by Pawel Halasa.
 *
 */
public class FileSelectBox extends JPanel implements ActionListener {

    private JButton openFileButton, clearButton;
    private JTextField fileNameField;
    private String currentDirectory, currentFile;
    private FileSelectListener listener;

    /**
     * The constructor of FileSelectBox
     *
     * @param listener Class to be informed about selected files
     */
    public FileSelectBox(FileSelectListener listener, int boxMode) {
        this.listener = listener;
        Box fileBox;
        if (boxMode == 1)
            fileBox = Box.createHorizontalBox();
        else
            fileBox = Box.createVerticalBox();
        add(fileBox);

        fileBox.add(fileNameField = new JTextField("", 15));
        fileNameField.addActionListener(this);

        if (boxMode == 1)
            fileBox.add(Box.createHorizontalStrut(3));
        else
            fileBox.add(Box.createVerticalStrut(3));

        Box buttonBox = Box.createHorizontalBox();
        fileBox.add(buttonBox);
        buttonBox.add(openFileButton = new JButton("Open"));
        openFileButton.addActionListener(this);
        buttonBox.add(Box.createHorizontalStrut(3));
        buttonBox.add(clearButton = new JButton("Clear"));
        clearButton.addActionListener(this);
    }

    /**
     * The constructor of FileSelectBox
     *
     * @param listener Class to be informed about selected files
     * @param selectedPath File selected at start
     */
    public FileSelectBox(FileSelectListener listener, int boxMode, File selectedPath) {
        this(listener, boxMode);
        if (selectedPath == null) return;
        currentDirectory = selectedPath.getParent();
        if (currentDirectory == null) currentDirectory = selectedPath.getPath();
        currentFile = selectedPath.getName();
        if (!currentFile.equals("")) {
            acceptFile(selectedPath);
//            fileNameField.setText(selectedPath.getPath());
//            listener.fileSelected(selectedPath);
        }
    }

    public void actionPerformed(ActionEvent e) {
        Object s = e.getSource();
        if (s == openFileButton) {
            JFileChooser chooser = new JFileChooser(currentDirectory);
            chooser.setAcceptAllFileFilterUsed(false);
            int returnVal = chooser.showOpenDialog(this);
            if (returnVal == JFileChooser.APPROVE_OPTION) {
                acceptFile(chooser.getSelectedFile());
            }
        } else if (s == fileNameField) {
            acceptFile(new File(fileNameField.getText()));
        } else if (s == clearButton) {
            currentFile = "";
            fileNameField.setText("");
            if (listener != null) listener.fileSelected(null);
        }
    }

    private void acceptFile(File file) {
        if (!file.exists()) {
            JOptionPane.showMessageDialog(this, "Cannot find file " + file.getPath(),
                    "Loading Error", JOptionPane.ERROR_MESSAGE);
            fileNameField.setText(currentDirectory + currentFile);
            return;
        }
        currentDirectory = file.getParent();
        currentFile = file.getName();
        fileNameField.setText(file.getPath());
        if (listener != null) listener.fileSelected(file);
    }
}
