package imagecomparer.stream;

import javax.imageio.stream.ImageInputStreamImpl;
import javax.imageio.stream.ImageInputStream;
import java.io.IOException;

/**
 * Class:           imagecomparer.stream.DelimitedImageInputStream
 * Version:         ?
 * Date:            2004-04-25 10:58:51
 *
 * Description:     ?
 *
 * COPYRIGHT:
 *
 * This software module was originally developed by Pawel Halasa.
 * 
 */

public class DelimitedImageInputStream extends ImageInputStreamImpl {

    private ImageInputStream in;
    static protected int bytesLimit = Integer.MAX_VALUE;
    protected int available = 0;
    static private int savedLimit;

    public DelimitedImageInputStream(ImageInputStream is) {
        super();
        in = is;
        available = bytesLimit;
    }

    public static void pause() {
        if (bytesLimit != 0) savedLimit = bytesLimit;
        bytesLimit = 0;
    }

    public static void resume() {
        if (bytesLimit == 0) bytesLimit = savedLimit;
    }

    public static void setCapacity(int cap) {
        bytesLimit = cap / 8;
    }

    public static int getCapacity() {
        return bytesLimit * 8;
    }

    public void restartSteam() throws IOException {
        seek(0);
        available = bytesLimit;
    }

    /*
     * Reads a single byte from the stream and returns it as an
     * <code>int</code> between 0 and 255.  If EOF is reached,
     * <code>-1</code> is returned.
     *
     * @return the value of the next byte in the stream, or <code>-1</code>
     * if EOF is reached.
     *
     * @exception IOException if the stream has been closed.
     */
    public int read() throws IOException {
        checkAvailability(1);
        streamPos++;
        bitOffset = 0;
        return in.read();
    }

    public int read(byte[] b, int off, int len) throws IOException {
        int res;

        checkAvailability(len);
        res = in.read(b, off, len);
        if (res > 0) {
            available -= res;
            streamPos += res;
        }
        bitOffset = 0;
        return res;
    }

    private void checkAvailability(int len) {
        while (available < len) {
            try {
                Thread.sleep(100);
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
            available += bytesLimit;
        }
    }

    public void seek(long pos) throws IOException {
        in.seek(pos);
        streamPos = pos;
    }
}
